@@ -306,6 +306,7 @@ pub struct Grid {
     pub link_handler: Rc<RefCell<LinkHandler>>,
     pub ring_bell: bool,
     scrollback_buffer_lines: usize,
+    pub mouse_mode: bool,
 }
 
 impl Debug for Grid {
@@ -363,6 +364,7 @@ impl Grid {
             link_handler,
             ring_bell: false,
             scrollback_buffer_lines: 0,
+            mouse_mode: false,
         }
     }
     pub fn render_full_viewport(&mut self) {
@@ -812,30 +814,31 @@ impl Grid {
         }
     }
     pub fn rotate_scroll_region_up(&mut self, count: usize) {
-        if let Some((scroll_region_top, scroll_region_bottom)) = self.scroll_region {
+        if let Some((scroll_region_top, scroll_region_bottom)) = self
+            .scroll_region
+            .or(Some((0, self.height.saturating_sub(1))))
+        {
             for _ in 0..count {
-                let columns = VecDeque::from(vec![EMPTY_TERMINAL_CHARACTER; self.width]);
-                if scroll_region_bottom < self.viewport.len() {
-                    self.viewport.remove(scroll_region_bottom);
-                }
-                if scroll_region_top < self.viewport.len() {
-                    self.viewport
-                        .insert(scroll_region_top, Row::from_columns(columns).canonical());
+                if self.cursor.y >= scroll_region_top && self.cursor.y <= scroll_region_bottom {
+                    self.pad_lines_until(scroll_region_bottom, EMPTY_TERMINAL_CHARACTER);
+                    if self.viewport.get(scroll_region_bottom).is_some() {
+                        self.viewport.remove(scroll_region_bottom);
+                    }
                 }
             }
             self.output_buffer.update_all_lines(); // TODO: only update scroll region lines
         }
     }
     pub fn rotate_scroll_region_down(&mut self, count: usize) {
-        if let Some((scroll_region_top, scroll_region_bottom)) = self.scroll_region {
+        if let Some((scroll_region_top, scroll_region_bottom)) = self
+            .scroll_region
+            .or(Some((0, self.height.saturating_sub(1))))
+        {
             for _ in 0..count {
-                let columns = VecDeque::from(vec![EMPTY_TERMINAL_CHARACTER; self.width]);
-                self.viewport.remove(scroll_region_top);
-                if self.viewport.len() > scroll_region_top {
-                    self.viewport
-                        .insert(scroll_region_bottom, Row::from_columns(columns).canonical());
-                } else {
-                    self.viewport.push(Row::from_columns(columns).canonical());
+                if self.cursor.y >= scroll_region_top && self.cursor.y <= scroll_region_bottom {
+                    self.pad_lines_until(scroll_region_top, EMPTY_TERMINAL_CHARACTER);
+                    self.viewport.remove(scroll_region_top);
+                    self.pad_lines_until(scroll_region_bottom, EMPTY_TERMINAL_CHARACTER);
                 }
             }
             self.output_buffer.update_all_lines(); // TODO: only update scroll region lines
@@ -947,6 +950,7 @@ impl Grid {
                     row.insert_character_at(terminal_character, self.cursor.x);
                 } else {
                     row.add_character_at(terminal_character, self.cursor.x);
+                    // self.move_cursor_forward_until_edge(count_to_move_cursor);
                 }
                 self.output_buffer.update_line(self.cursor.y);
             }
@@ -967,6 +971,9 @@ impl Grid {
     pub fn add_character(&mut self, terminal_character: TerminalCharacter) {
         // TODO: try to separate adding characters from moving the cursors in this function
         let character_width = terminal_character.width;
+        if character_width == 0 {
+            return;
+        }
         if self.cursor.x + character_width > self.width {
             if self.disable_linewrap {
                 return;
@@ -1059,8 +1066,11 @@ impl Grid {
     }
 
     fn pad_current_line_until(&mut self, position: usize) {
+        if self.viewport.get(self.cursor.y).is_none() {
+            self.pad_lines_until(self.cursor.y, EMPTY_TERMINAL_CHARACTER);
+        }
         let current_row = self.viewport.get_mut(self.cursor.y).unwrap();
-        for _ in current_row.len()..position {
+        for _ in current_row.width()..position {
             current_row.push(EMPTY_TERMINAL_CHARACTER);
         }
         self.output_buffer.update_line(self.cursor.y);
@@ -1303,9 +1313,9 @@ impl Grid {
         self.mark_for_rerender();
     }
 
-    pub fn end_selection(&mut self, end: Option<&Position>) {
+    pub fn end_selection(&mut self, end: &Position) {
         let old_selection = self.selection;
-        self.selection.end(end);
+        self.selection.end(*end);
         self.update_selected_lines(&old_selection, &self.selection.clone());
         self.mark_for_rerender();
     }
@@ -1391,7 +1401,11 @@ impl Grid {
         // for now trim after building the selection to handle whitespace in wrapped lines
         let selection: Vec<_> = selection.iter().map(|l| l.trim_end()).collect();
 
-        Some(selection.join("\n"))
+        if selection.is_empty() {
+            None
+        } else {
+            Some(selection.join("\n"))
+        }
     }
 
     fn update_selected_lines(&mut self, old_selection: &Selection, new_selection: &Selection) {
@@ -1767,6 +1781,9 @@ impl Perform for Grid {
                     Some(7) => {
                         self.disable_linewrap = true;
                     }
+                    Some(1006) => {
+                        self.mouse_mode = false;
+                    }
                     _ => {}
                 };
             } else if let Some(4) = params_iter.next().map(|param| param[0]) {
@@ -1802,6 +1819,7 @@ impl Perform for Grid {
                             Some((current_lines_above, current_viewport, current_cursor));
                         self.clear_viewport_before_rendering = true;
                         self.scrollback_buffer_lines = self.recalculate_scrollback_buffer_count();
+                        self.output_buffer.update_all_lines(); // make sure the screen gets cleared in the next render
                     }
                     Some(1) => {
                         self.cursor_key_mode = true;
@@ -1819,6 +1837,9 @@ impl Perform for Grid {
                     Some(7) => {
                         self.disable_linewrap = false;
                     }
+                    Some(1006) => {
+                        self.mouse_mode = true;
+                    }
                     _ => {}
                 };
             } else if let Some(4) = params_iter.next().map(|param| param[0]) {
@@ -2172,14 +2193,34 @@ impl Row {
         }
         absolute_index
     }
+    pub fn absolute_character_index_and_position_in_char(&self, x: usize) -> (usize, usize) {
+        // returns x's width aware index as well as its position inside the wide char (eg. 1 if
+        // it's in the middle of a 2-char wide character)
+        let mut accumulated_width = 0;
+        let mut absolute_index = x;
+        let mut position_inside_character = 0;
+        for (i, terminal_character) in self.columns.iter().enumerate() {
+            accumulated_width += terminal_character.width;
+            absolute_index = i;
+            if accumulated_width > x {
+                let character_start_position = accumulated_width - terminal_character.width;
+                position_inside_character = x - character_start_position;
+                break;
+            }
+        }
+        (absolute_index, position_inside_character)
+    }
     pub fn add_character_at(&mut self, terminal_character: TerminalCharacter, x: usize) {
         match self.width_cached().cmp(&x) {
             Ordering::Equal => {
+                // adding the character at the end of the current line
                 self.columns.push_back(terminal_character);
                 // this is unwrapped because this always happens after self.width_cached()
                 *self.width.as_mut().unwrap() += terminal_character.width;
             }
             Ordering::Less => {
+                // adding the character after the end of the current line
+                // we pad the line up to the character and then add it
                 let width_offset = self.excess_width_until(x);
                 self.columns
                     .resize(x.saturating_sub(width_offset), EMPTY_TERMINAL_CHARACTER);
@@ -2187,25 +2228,38 @@ impl Row {
                 self.width = None;
             }
             Ordering::Greater => {
-                // wide-character-aware index, where each character is counted once
-                let absolute_x_index = self.absolute_character_index(x);
+                // adding the character in the middle of the line
+                // we replace the character at its position
+                let (absolute_x_index, position_inside_character) =
+                    self.absolute_character_index_and_position_in_char(x);
                 let character_width = terminal_character.width;
                 let replaced_character =
                     std::mem::replace(&mut self.columns[absolute_x_index], terminal_character);
                 match character_width.cmp(&replaced_character.width) {
                     Ordering::Greater => {
-                        // this is done in a verbose manner because of performance
-                        let width_difference = character_width - replaced_character.width;
-                        for _ in 0..width_difference {
-                            let position_to_remove = absolute_x_index + 1;
-                            if self.columns.get(position_to_remove).is_some() {
-                                self.columns.remove(position_to_remove);
+                        // the replaced character is narrower than the current character
+                        // (eg. we added a wide emoji in place of an English character)
+                        // we remove the character after it to make room
+                        let position_to_remove = absolute_x_index + 1;
+                        if let Some(removed) = self.columns.remove(position_to_remove) {
+                            if removed.width > 1 {
+                                // the character we removed is a wide character itself, so we add
+                                // padding
+                                self.columns
+                                    .insert(position_to_remove, EMPTY_TERMINAL_CHARACTER);
                             }
                         }
                     }
                     Ordering::Less => {
-                        let width_difference = replaced_character.width - character_width;
-                        for _ in 0..width_difference {
+                        // the replaced character is wider than the current character
+                        // (eg. we added an English character in place of a wide emoji)
+                        // we must make sure to add padding either before the character we added
+                        // or after it, depending on our position inside said removed wide character
+                        // TODO: support characters wider than 2
+                        if position_inside_character > 0 {
+                            self.columns
+                                .insert(absolute_x_index, EMPTY_TERMINAL_CHARACTER);
+                        } else {
                             self.columns
                                 .insert(absolute_x_index + 1, EMPTY_TERMINAL_CHARACTER);
                         }
@@ -2232,14 +2286,14 @@ impl Row {
         self.width = None;
     }
     pub fn replace_character_at(&mut self, terminal_character: TerminalCharacter, x: usize) {
-        // this is much more performant than remove/insert
-        if x < self.columns.len() {
+        let absolute_x_index = self.absolute_character_index(x);
+        if absolute_x_index < self.columns.len() {
             self.columns.push_back(terminal_character);
-            // let character = self.columns.swap_remove_back(x);
-            let character = self.columns.swap_remove_back(x).unwrap(); // TODO: if let?
+            // this is much more performant than remove/insert
+            let character = self.columns.swap_remove_back(absolute_x_index).unwrap();
             let excess_width = character.width.saturating_sub(1);
             for _ in 0..excess_width {
-                self.columns.insert(x, terminal_character);
+                self.columns.insert(absolute_x_index, terminal_character);
             }
         }
         self.width = None;
