@@ -13,12 +13,14 @@ use std::fmt::Debug;
 use std::os::unix::io::RawFd;
 use std::rc::Rc;
 use std::time::{self, Instant};
+use zellij_tile::prelude::Style;
 use zellij_utils::pane_size::Offset;
 use zellij_utils::{
     pane_size::{Dimension, PaneGeom},
     position::Position,
+    shared::make_terminal_title,
     vte,
-    zellij_tile::data::{InputMode, Palette, PaletteColor},
+    zellij_tile::data::{InputMode, PaletteColor},
 };
 
 pub const SELECTION_SCROLL_INTERVAL_MS: u64 = 10;
@@ -40,7 +42,7 @@ pub struct TerminalPane {
     pub geom: PaneGeom,
     pub geom_override: Option<PaneGeom>,
     pub active_at: Instant,
-    pub colors: Palette,
+    pub style: Style,
     vte_parser: vte::Parser,
     selection_scrolled_at: time::Instant,
     content_offset: Offset,
@@ -137,6 +139,19 @@ impl Pane for TerminalPane {
                     return "OA".as_bytes().to_vec();
                 }
             }
+
+            [27, 91, 72] => {
+                // home key
+                if self.grid.cursor_key_mode {
+                    return vec![27, 79, 72]; // ESC O H
+                }
+            }
+            [27, 91, 70] => {
+                // end key
+                if self.grid.cursor_key_mode {
+                    return vec![27, 79, 70]; // ESC O F
+                }
+            }
             [27, 91, 66] => {
                 // down arrow
                 if self.grid.cursor_key_mode {
@@ -202,7 +217,7 @@ impl Pane for TerminalPane {
                     .selection
                     .contains_row(character_chunk.y.saturating_sub(content_y))
                 {
-                    let background_color = match self.colors.bg {
+                    let background_color = match self.style.colors.bg {
                         PaletteColor::Rgb(rgb) => AnsiCode::RgbCode(rgb),
                         PaletteColor::EightBit(col) => AnsiCode::ColorIndex(col),
                     };
@@ -303,6 +318,16 @@ impl Pane for TerminalPane {
         }
         vte_output
     }
+    fn render_terminal_title(&mut self, input_mode: InputMode) -> String {
+        let pane_title = if self.pane_name.is_empty() && input_mode == InputMode::RenamePane {
+            "Enter name..."
+        } else if self.pane_name.is_empty() {
+            self.grid.title.as_deref().unwrap_or(&self.pane_title)
+        } else {
+            &self.pane_name
+        };
+        make_terminal_title(pane_title)
+    }
     fn update_name(&mut self, name: &str) {
         match name {
             "\0" => {
@@ -420,7 +445,7 @@ impl Pane for TerminalPane {
         self.set_should_render(true);
     }
 
-    fn end_selection(&mut self, end: Option<&Position>, _client_id: ClientId) {
+    fn end_selection(&mut self, end: &Position, _client_id: ClientId) {
         self.grid.end_selection(end);
         self.set_should_render(true);
     }
@@ -448,13 +473,17 @@ impl Pane for TerminalPane {
     fn borderless(&self) -> bool {
         self.borderless
     }
+
+    fn mouse_mode(&self) -> bool {
+        self.grid.mouse_mode
+    }
 }
 
 impl TerminalPane {
     pub fn new(
         pid: RawFd,
         position_and_size: PaneGeom,
-        palette: Palette,
+        style: Style,
         pane_index: usize,
         pane_name: String,
         link_handler: Rc<RefCell<LinkHandler>>,
@@ -463,8 +492,8 @@ impl TerminalPane {
         let grid = Grid::new(
             position_and_size.rows.as_usize(),
             position_and_size.cols.as_usize(),
-            palette,
-            link_handler.clone(),
+            style.colors,
+            link_handler,
         );
         TerminalPane {
             frame: HashMap::new(),
@@ -476,7 +505,7 @@ impl TerminalPane {
             geom_override: None,
             vte_parser: vte::Parser::new(),
             active_at: Instant::now(),
-            colors: palette,
+            style,
             selection_scrolled_at: time::Instant::now(),
             pane_title: initial_pane_title,
             pane_name,
