@@ -4,8 +4,8 @@ use crate::tab::Pane;
 use ::insta::assert_snapshot;
 use std::cell::RefCell;
 use std::rc::Rc;
+use zellij_tile::prelude::Style;
 use zellij_utils::pane_size::PaneGeom;
-use zellij_utils::zellij_tile::data::Palette;
 
 use std::fmt::Write;
 
@@ -17,11 +17,11 @@ pub fn scrolling_inside_a_pane() {
     fake_win_size.rows.set_inner(20);
 
     let pid = 1;
-    let palette = Palette::default();
+    let style = Style::default();
     let mut terminal_pane = TerminalPane::new(
         pid,
         fake_win_size,
-        palette,
+        style,
         0,
         String::new(),
         Rc::new(RefCell::new(LinkHandler::new())),
