@@ -8,6 +8,7 @@ use crate::{
 };
 use std::convert::TryInto;
 use std::path::PathBuf;
+use zellij_tile::prelude::Style;
 use zellij_utils::envs::set_session_name;
 use zellij_utils::input::layout::LayoutTemplate;
 use zellij_utils::input::options::Clipboard;
@@ -94,7 +95,7 @@ fn create_new_tab(size: Size) -> Tab {
     let senders = ThreadSenders::default().silently_fail_on_send();
     let max_panes = None;
     let mode_info = ModeInfo::default();
-    let colors = Palette::default();
+    let style = Style::default();
     let draw_pane_frames = true;
     let client_id = 1;
     let session_is_mirrored = true;
@@ -111,8 +112,8 @@ fn create_new_tab(size: Size) -> Tab {
         os_api,
         senders,
         max_panes,
+        style,
         mode_info,
-        colors,
         draw_pane_frames,
         connected_clients,
         session_is_mirrored,
