@@ -20,6 +20,6 @@ pub use nix;
 pub use serde;
 pub use serde_yaml;
 pub use signal_hook;
-pub use termion;
+pub use termwiz;
 pub use vte;
 pub use zellij_tile;
